@@ -11,8 +11,6 @@ if __name__ == "__main__":
     parser = ArgumentParser(prog="Chippy", description="Run chip-8 emulator.")
     parser.add_argument("-l", "--list", action="store_true",
                         help="list available ROMs")
-    parser.add_argument("-d", "--disassemble", metavar="ROM",
-                        help="disassemble chip-8 program")
     parser.add_argument("-p", "--play", metavar="ROM", help="load chip-8 ROM")
     parser.add_argument("-c", "--colors", default=config.color_scheme,
                         help=f"color scheme (default={config.color_scheme!r})")
@@ -25,7 +23,5 @@ if __name__ == "__main__":
 
     if args.list:
         app.list_roms()
-    elif args.disassemble:
-        app.disassemble(args.disassemble)
     elif args.play:
         app.run(args.play, config)
