@@ -5,7 +5,6 @@ import sys
 
 from .chippy import Chippy
 from .config import Config
-from .debug import Disassembler
 
 def list_roms():
     """List avaiable ROMs."""
@@ -31,11 +30,3 @@ def run(program, config=Config()):
     chippy = Chippy(config)
     chippy.load(rom)
     chippy.run()
-
-def disassemble(program):
-    """Disassemble chip-8 program."""
-    rom = find_rom(program)
-    if rom is None:
-        print(f"Program '{program}' not found.", file=sys.stderr)
-        sys.exit(errno.ENOENT)
-    Disassembler.run(rom)
